@@ -1,4 +1,3 @@
-# -*- coding: UTF-8 -*-
 from crispy_forms.helper import FormHelper
 from crispy_forms.layout import Submit
 from django.utils.translation import ugettext_lazy as _
@@ -10,7 +9,7 @@ class RequestInFormKwargsMixin(object):
     Attention: Have to be removed in the init of the form (via .pop())
     """
     def get_form_kwargs(self):
-        kwargs = super(RequestInFormKwargsMixin, self).get_form_kwargs()
+        kwargs = super().get_form_kwargs()
         kwargs.update({'request': self.request})
         return kwargs
 
@@ -24,10 +23,10 @@ class CrispyLayoutFormMixin(object):
         self.helper = FormHelper()
         self.helper.form_class = 'form-horizontal form-bordered form-row-stripped'
         self.helper.form_method = 'post'
-        self.helper.add_input(Submit('submit_button', _(u'Speichern')))
+        self.helper.add_input(Submit('submit_button', _('Speichern')))
         self.helper.form_tag = True
         self.helper.label_class = 'col-md-3'
         self.helper.field_class = 'col-md-9'
         self.helper.label_size = ' col-md-offset-3'
 
-        super(CrispyLayoutFormMixin, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
